package sendmail.util;

import java.io.*;
import java.util.*;
import javax.swing.*;
import java.awt.*;

/**
 * Title:        SendMail
 * Description:  This application simplifies sending the same email to different addresses with different subject."
 * Copyright:    Copyright (c) 2002
 * Company:      NPI
 * @author Phanindra K Nayani
 * @version 1.0
 */

public class GeneralUtility {


    /**
     * Method for selecting the files and directories according to the options provided
     * through the parameters. This will use JFileChooser, a swing component that gives
     * a fancy GUI for selecting files and directories.
     *
     * @param   fileSelectionMode   to specify to select only file or directories only or both
     * @param   parent    parent GUI component invoking this method
     * @param   currentDirectoryPath    initial directory to be shown in the GUI for
     *                                  the selection of  files/directories
     * @return  Returns the vector having the java.io.File objects representing
     *          file and/or directory objects selected
     */
    public static String selectFile(Component parent){
        JFileChooser fileChooser = null;
        fileChooser = new JFileChooser(".");

        fileChooser.setFileSelectionMode(JFileChooser.FILES_ONLY);
        fileChooser.setMultiSelectionEnabled(false);

        if(fileChooser.showOpenDialog(parent) == JFileChooser.CANCEL_OPTION) {
            return(null);
        }
        java.io.File selectedFile = fileChooser.getSelectedFile();
        return(selectedFile.getPath());
    }


    /**
     * Method for getting the content of a file whose path is passed as a parameter.
     *
     * @param   pathName   path of the file whose content is to be returned
     * @return  Returns the content or data of the file specified
     */
    public static String getFileContent(String pathName) throws IOException {
           int numCharsRead = 1;
           char c = 'x';
           String allLinesOfText = "";
           char someChars[] = new char[80];

           FileReader fileReader = new FileReader( pathName );
           while(numCharsRead > 0) {
                numCharsRead = fileReader.read(someChars);
                //System.out.println("***  numCharsRead="+numCharsRead+" , CharsRead="+someChars);
                if(numCharsRead > 0) {
                    allLinesOfText = allLinesOfText.concat( new String(someChars, 0, numCharsRead) );
                }
           }
           //System.out.println("***  allLinesOfText = "+allLinesOfText);
           if( allLinesOfText.length() > 2  && (allLinesOfText.charAt(allLinesOfText.length()-2) != '\r' || allLinesOfText.charAt(allLinesOfText.length()-1) != '\n') ) {
                allLinesOfText = allLinesOfText.concat("\r\n");
           }
           //System.out.println("***  allLinesOfText = "+allLinesOfText);

           return(allLinesOfText);
    }

    public static Vector getNextToAndSubject(String fileName, String defaultSubject) throws Exception{
         /*  if(lineTokenizer.hasMoreTokens() != true) {
                                            System.out.println("Has no more eleements");
                                            return null;
           }
*/
           //String lot = lineTokenizer.nextToken();
           //System.out.println("Next Line : "+lot);
           Vector tokens = new Vector();
           StringTokenizer entryTokenizer = new StringTokenizer(getFileContent(fileName), "\n\r\f");
           String emailID, subject, lot;
           int i=-1, commaIndex;

           while(entryTokenizer.hasMoreTokens() == true) {
               ++i;
               lot = entryTokenizer.nextToken().trim();
               if(lot.length() <= 0)
                   continue;
               //System.out.println("NExt LOT : "+lot);
               commaIndex =  lot.indexOf(",");
               if(commaIndex==0) {
                  System.out.println("Line #"+i+" has error, it dont start with email address : "+lot);
                  continue;
               }
               if(commaIndex<0) {
                   if(validateEMailID(lot) == true) {
                       tokens.add(lot);
                       tokens.add(defaultSubject);
                   }
                   else {
                        System.out.println("Line #"+i+" has error, it dont start with email address : "+lot);
                   }
                   continue;
               }
               else {
                    //add the email id
                    emailID = lot.substring(0, commaIndex).trim();
                    if(validateEMailID(emailID) ==  true) {
                        tokens.add(emailID);
                    }
                    else {
                        System.out.println("Line #"+i+" has error, it dont start with email address : "+lot);
                        continue;
                   }

                    //Now extract subject

                    //if line is like "phani78@hotmail.com,"
                    if(commaIndex == lot.length()-1) {
                        tokens.add(defaultSubject);
                        continue;
                    }
                    lot = lot.substring(commaIndex+1).trim();
                    //if line is like "phani78@hotmail.com,,"
                    commaIndex = lot.indexOf(',');
                    //if line is like "phani78@hotmail.com,mysubject"
                    if(commaIndex <= 0) {
                        if(lot.length() > 0) {
                            tokens.add(lot);
                        }
                        else {
                             tokens.add(defaultSubject);
                        }
                    }
                    else {
                         tokens.add(lot.substring(0, commaIndex));
                    }
                    continue;
               }
           }
           return(tokens);
    }

    public static boolean validateEMailID(String emailID) {
           if(emailID==null || emailID.length()<=4 || emailID.indexOf(" ")>=0 ||  emailID.indexOf("\t")>=0)
               return(false);
           int i = emailID.indexOf("@");
           int j = emailID.lastIndexOf(".");
           int len = emailID.length();
           if(i<=0 || i==(j-1) || i>j || j==(len-1))
                   return(false);
           return(true);
    }
}