package sendmail.mail;

import sendmail.util.*;

import java.io.*;
import java.util.*;

import javax.mail.*;
import javax.mail.internet.*;
import javax.mail.internet.MimeMultipart;
import javax.activation.*;


/**
 * Title:        SendMail
 * Description:  This application simplifies sending the same email to different addresses with different subject."
 * Copyright:    Copyright (c) 2002
 * Company:      NPI
 * @author Phanindra K Nayani
 * @version 1.0
 */

public class Postman {

  Properties props;
  Store store;
  MimeMessage mimeMessage;
  Multipart multipart;
  InternetAddress fromAddress;
  Session session;

  MimeBodyPart mimeBodyPart;
  MimeBodyPart mimeBodyPart1;
  MimeBodyPart mimeBodyPart2;
  MimeBodyPart mimeBodyPart3;

  FileDataSource fileDataSource;
  FileDataSource fileDataSource1;
  FileDataSource fileDataSource2;
  FileDataSource fileDataSource3;

  public Postman() {
  }


  public void reinitialize(String from, String smtpAddress, String popAddress, String message, String username, String password, String atthachmentFileName1, String atthachmentFileName2, String atthachmentFileName3) throws Exception {
      initialize(from, smtpAddress, popAddress, message, username, password, atthachmentFileName1, atthachmentFileName2, atthachmentFileName3);
  }


  public void initialize(String from, String smtpAddress, String popAddress, String message, String username, String password, String atthachmentFileName1, String atthachmentFileName2, String atthachmentFileName3) throws Exception{

          mimeBodyPart = null;
          mimeBodyPart1 = null;
          mimeBodyPart2 = null;
          mimeBodyPart3 = null;

          fileDataSource = null;
          fileDataSource1 = null;
          fileDataSource2 = null;
          fileDataSource3 = null;

          props = new Properties();
          props.put("mail.smtp.host", smtpAddress);
          //props.put("mail.user", "nphanindrakumar");
          session = Session.getDefaultInstance(props, null);
          session.setDebug(true);


                // Pop Authenticate yourself
                store = session.getStore("pop3");
                store.connect(popAddress, username, password);

                fromAddress = new InternetAddress(from);

    //msg.addRecipient(Message.RecipientType.TO, new InternetAddress(to));
    //msg.setSubject("Hello JavaMail");
    //msg.setText("Welcome to Yahoo's JavaMail");


          // create a message
    //msg.setSubject("MyResSubject");

              //create container for mail body and attachments
              multipart = new MimeMultipart();

              // create and fill the message/mail body
              mimeBodyPart = new MimeBodyPart();
              mimeBodyPart.setText(message);
              multipart.addBodyPart(mimeBodyPart);

              //add attachment # 1
              if(atthachmentFileName1 != null && atthachmentFileName1.trim().length()>0) {
                  mimeBodyPart1 = new MimeBodyPart();
                  // attach the file to the message
                  fileDataSource1=  new FileDataSource(atthachmentFileName1);
                  mimeBodyPart1.setDataHandler(new DataHandler(fileDataSource1));
                  mimeBodyPart1.setFileName(new File(atthachmentFileName1).getName());
                  multipart.addBodyPart(mimeBodyPart1);
              }

              //add attachment # 2
              if(atthachmentFileName2 != null && atthachmentFileName2.trim().length()>0) {
                  mimeBodyPart2 = new MimeBodyPart();
                  // attach the file to the message
                  fileDataSource2=  new FileDataSource(atthachmentFileName2);
                  mimeBodyPart2.setDataHandler(new DataHandler(fileDataSource2));
                  mimeBodyPart2.setFileName(new File(atthachmentFileName2).getName());
                  multipart.addBodyPart(mimeBodyPart2);
              }

              //add attachment # 3
              if(atthachmentFileName3 != null && atthachmentFileName3.trim().length()>0) {
                  mimeBodyPart3 = new MimeBodyPart();
                  // attach the file to the message
                  fileDataSource3=  new FileDataSource(atthachmentFileName3);
                  mimeBodyPart3.setDataHandler(new DataHandler(fileDataSource3));
                  mimeBodyPart3.setFileName(new File(atthachmentFileName3).getName());
                  multipart.addBodyPart(mimeBodyPart3);
              }



  }

  public void sendMail(String to, String anotherTo,  String subject) throws Exception {

                 // Define message
                 mimeMessage = new MimeMessage(session);
                 mimeMessage.setFrom(fromAddress);

                 mimeMessage.addRecipient(Message.RecipientType.TO, new InternetAddress(to));
                 if(anotherTo != null && anotherTo.trim().length()>0) {
                     mimeMessage.addRecipient(Message.RecipientType.TO, new InternetAddress(anotherTo));
                 }
                 mimeMessage.setSubject(subject);

                 mimeMessage.setContent(multipart);

                 // send the message
                 Transport.send(mimeMessage);

  }
}//End of class def


